Summary: The GNU libc libraries.
Name: glibc
Version: 2.3.2
Release: 16tr
License: LGPL
Group: Trustix Official
Source: ftp://ftp.gnu.org/gnu/glibc/%{name}-%{version}.tar.bz2
Source1: ftp://ftp.gnu.org/gnu/glibc/%{name}-linuxthreads-%{version}.tar.bz2
Source2: locales-gen
Source3: nsswitch.conf
Source4: glibc_post_upgrade.c
Source5: nscd.init
Patch1: glibc-2.2.5-gcc-3.2.patch
# Fixes paths
Patch2: glibc-2.2.5-paths.patch
# Several security updates:
Patch3: glibc-2.3-resolver.patch
Patch4: glibc-2.2-resolver2.patch
Patch5: glibc-2.1.3-owl-QFIXEDSZ-underfills.diff
Patch6: glibc-2.3-paths.h.patch
Patch7: glibc-2.3.3-gcc33sscan.patch
PAtch8: glibc-getgrouplist.patch
Patch9: glibc-2.3.2-tempfile.patch
Buildroot: /var/tmp/%{name}-root
BuildRequires: binutils >= 2.13
Autoreq: false

%description
The glibc package contains standard libraries which are used by
multiple programs on the system. In order to save disk space and
memory, as well as to make upgrading easier, common system code is
kept in one place and shared between programs. This particular package
contains the most important sets of shared libraries: the standard C
library and the standard math library. Without these two libraries, a
Linux system will not function.  The glibc package also contains
national language (locale) support and timezone databases.

%package devel
Summary: Header and object files for development using standard C libraries.
Group: Trustix Official
Obsoletes: libc-debug, libc-headers, libc-devel, linuxthreads-devel
Obsoletes: glibc-debug
Requires: linux-headers
BuildRequires: linux-headers
Autoreq: true

%description devel
The glibc-devel package contains the header and object files necessary
for developing programs which use the standard C libraries (which are
used by nearly all programs).  If you are developing programs which
will use the standard C libraries, your system needs to have these
standard header and object files available in order to create the
executables.

Install glibc-devel if you are going to develop programs which will
use the standard C libraries.

%package profile
Summary: The GNU libc libraries, including support for gprof profiling.
Group: Trustix Official
Obsoletes: libc-profile
Autoreq: true

%description profile
The glibc-profile package includes the GNU libc libraries and support
for profiling using the gprof program.  Profiling is analyzing a
program's functions to see how much CPU time they use and determining
which functions are calling other functions during execution.  To use
gprof to profile a program, your program needs to use the GNU libc
libraries included in glibc-profile (instead of the standard GNU libc
libraries included in the glibc package).

If you are going to use the gprof program to profile a program, you'll
need to install the glibc-profile program.

%package -n nscd
Summary: A Name Service Caching Daemon (nscd).
Group: Trustix Official
Conflicts: kernel < 2.2.0
Prereq: chkconfig, tsl-utils
Autoreq: true

%description -n nscd
Nscd caches name service lookups and can dramatically improve
performance with NIS+, and may help with DNS as well. Note that you
can't use nscd with 2.0 kernels because of bugs in the kernel-side
thread support. Unfortunately, nscd happens to hit these bugs
particularly hard.

Install nscd if you need a name service lookup caching daemon, and
you're not using a version 2.0 kernel.

%package locales
Summary: Locale enviroment settings
Group: Trustix Official
Conflicts: kernel < 2.2.0
Prereq: /sbin/chkconfig
Requires: glibc
Autoreq: true

%description locales
Glibc-locales includes the data files for the glibc national language support 
(locale). The files necessary for the 'en_US ISO-8859-1' locale is included in 
the main package.

Install locales if you need extra native language support.

%prep
%setup -q -a 1 -q -n glibc-%{version} 
find . -type f -size 0 -o -name "*.orig" -exec rm -f {} \;
%define date    %(echo `LC_ALL="C" date +"%a %b %d %Y"`)
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%build
rm -rf build-$RPM_ARCH-linux
mkdir build-$RPM_ARCH-linux ; cd build-$RPM_ARCH-linux
BuildFlags="-mpentium \
	-D__USE_STRING_INLINES \
	-fstrict-aliasing \
	-mcpu=%{_target_cpu}"
CC=gcc 
CFLAGS="$BuildFlags -g -O3" 
export LD_LIBRARY_PATH=""
../configure 	--prefix=/usr \
		--enable-add-ons=yes \
		--enable-versioning=yes \
		--without-cvs \
		%{_target_cpu}-trustix-linux
 
make -r CFLAGS="$BuildFlags -g -O3" PARALLELMFLAGS=-s
# build the post-upgrade program.
gcc -static -Os %SOURCE4 -o glibc_post_upgrade

%install
mkdir -p $RPM_BUILD_ROOT
make install_root=$RPM_BUILD_ROOT install -C build-$RPM_ARCH-linux

# Get to know which locales are supported:
grep -v '#' < localedata/SUPPORTED | \
	sed "s|/| |" | \
	sed "s|\\\| |" | \
	grep -v 'SUPPORTED-LOCALES=' | \
	grep -v 'ja_JP.EUC-JP' | \
	grep -v 'ko_KR.EUC-KR' | \
	grep -v 'ko_KR.UTF-8' | \
	grep -v 'ru_RU.KOI8-R' | \
	grep -v 'zh_CN.GB18030' | \
	grep -v 'zh_CN.GBK' | \
	grep -v 'zh_TW.EUC-TW' \
	> supported_locales.txt
# create locales.conf:
echo '# This file define additional NLS-locales to be generated.' \
	> locales.conf
echo '# Uncomment any locale you want to be generated.' \
	>> locales.conf
echo '# Then run /usr/sbin/locales-gen to generate the choosen locales'\
	>> locales.conf

check='-1'
lang='null'
char='null'


for i in $(cat supported_locales.txt); do
	if (test "$check" = -1)
	then
		lang=$i
		check=1
	else
		char=$i
		check=-1
		echo "# $lang $char" >> locales.conf
	fi
done
echo -n '# This is the end.' >> locales.conf	 


mkdir -p $RPM_BUILD_ROOT/usr/share/locale
mkdir -p $RPM_BUILD_ROOT/usr/lib/locale

install -m 644 locales.conf \
	$RPM_BUILD_ROOT/etc/locales.conf

install -m 644 supported_locales.txt \
	$RPM_BUILD_ROOT/usr/share/locale/supported_locales.txt

# locales-gen
install -m 750 %SOURCE2 $RPM_BUILD_ROOT/usr/sbin/locales-gen

# the man pages for the linuxthreads require special attention
make -C linuxthreads/man
mkdir -p $RPM_BUILD_ROOT/usr/share/man/man3
install -m 0644 linuxthreads/man/*.3thr $RPM_BUILD_ROOT/usr/share/man/man3
gzip -9nvf $RPM_BUILD_ROOT/usr/share/man/man3/*.3thr
ln -sf libbsd-compat.a $RPM_BUILD_ROOT/usr/lib/libbsd.a

# This is for ncsd
install -m 644 nscd/nscd.conf $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/init.d
install -m 755 %{SOURCE5} $RPM_BUILD_ROOT/etc/init.d/nscd

# This is the nss config file
install -m 644 $RPM_SOURCE_DIR/nsswitch.conf $RPM_BUILD_ROOT/etc/

# The database support
mkdir -p $RPM_BUILD_ROOT/var/db

# Install the upgrade program
install -m 700 build-%{_target_cpu}-linux/glibc_post_upgrade $RPM_BUILD_ROOT/usr/sbin/glibc_post_upgrade

# Strip binaries
strip $RPM_BUILD_ROOT/sbin/* || :
strip $RPM_BUILD_ROOT/usr/bin/* || :
strip $RPM_BUILD_ROOT/usr/sbin/* || :

# Strip the .so's
strip $RPM_BUILD_ROOT/lib/*.so || :


# Create ghosts (-locales hack):
for i in $(cat supported_locales.txt | cut -d " " -f 1); do
	mkdir -p ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_MESSAGES
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_ADDRESS
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_COLLATE
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_CTYPE
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_IDENTIFICATION
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_MEASUREMENT
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_MONETARY
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_NAME
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_NUMERIC
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_PAPER
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_TELEPHONE
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_TIME
	touch ${RPM_BUILD_ROOT}/usr/lib/locale/$i/LC_MESSAGES/SYS_LC_MESSAGES
done

# Make ld.so.conf
touch $RPM_BUILD_ROOT/etc/ld.so.conf
chmod 644 $RPM_BUILD_ROOT/etc/ld.so.conf

# We dont have the info system in TSL-2.0
rm -rf $RPM_BUILD_ROOT/usr/share/info
rm -rf $RPM_BUILD_ROOT/usr/info

# /etc/localtime - Setting default localtime to GMT
rm -f $RPM_BUILD_ROOT/etc/localtime
cp -f $RPM_BUILD_ROOT/usr/share/zoneinfo/GMT $RPM_BUILD_ROOT/etc/localtime

# the last bit: more documentation
rm -rf documentation
mkdir documentation
cp linuxthreads/ChangeLog  documentation/ChangeLog.threads
cp linuxthreads/Changes documentation/Changes.threads
cp linuxthreads/README documentation/README.threads
cp linuxthreads/FAQ.html documentation/FAQ-threads.html
cp -r linuxthreads/Examples documentation/examples.threads
cp ChangeLog* documentation
gzip -9 documentation/ChangeLog*
exit 0

#%post -p /usr/sbin/glibc_post_upgrade

%postun -p /sbin/ldconfig

%pre devel
# this used to be a link and it is causing nightmares now
if [ -L /usr/include/scsi ] ; then
    rm -f /usr/include/scsi
fi

%pre -n nscd
# Check whether we need to add syslog user/group
if [ -z "`getent group nscd`" ] ; then
        /usr/sbin/groupadd -g 35 nscd
fi
if [ -z "`getent passwd nscd`" ] ; then
/usr/sbin/useradd -u 35 -g 35 -c "nscd" -s /bin/false nscd 2>/dev/null
fi

%post -n nscd
/sbin/chkconfig --add nscd
/sbin/restart_maybe nscd

%preun -n nscd
if [ $1 = 0 ] ; then
    /sbin/chkconfig --del nscd
fi

%post locales
. /usr/sbin/locales-gen

echo ''
echo 'Please edit the file /etc/locales.conf to manipulate which locales'
echo 'will be generated. Then issue the command "/usr/sbin/locales-gen"'
echo ''

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc README NEWS INSTALL FAQ BUGS NOTES PROJECTS hesiod/README.hesiod
%doc documentation/* 
%config(noreplace) /etc/ld.so.cache
%config(noreplace) /etc/ld.so.conf
%config(noreplace) /etc/localtime
%config(noreplace) /etc/nsswitch.conf
%config(noreplace) /etc/rpc

/lib/*
/sbin/*
/usr/bin/*
/usr/sbin/glibc_post_upgrade
/usr/sbin/iconvconfig
/usr/sbin/rpcinfo
/usr/sbin/zdump
/usr/sbin/zic
/usr/share/zoneinfo
/var/db

%files profile
%defattr(-,root,root)
/usr/lib/*_p.a

%files devel
%defattr(-,root,root)
/usr/include/*
/usr/lib/*.o
/usr/lib/*.so
/usr/lib/libBrokenLocale.a
/usr/lib/libanl.a
/usr/lib/libbsd-compat.a
/usr/lib/libbsd.a
/usr/lib/libc.a
/usr/lib/libc_nonshared.a
/usr/lib/libcrypt.a
/usr/lib/libdl.a
/usr/lib/libg.a
/usr/lib/libieee.a
/usr/lib/libm.a
/usr/lib/libmcheck.a
/usr/lib/libnsl.a
/usr/lib/libpthread.a
/usr/lib/libpthread_nonshared.a
/usr/lib/libresolv.a
/usr/lib/librpcsvc.a
/usr/lib/librt.a
/usr/lib/libutil.a
/usr/share/man/man3/*

%files locales
%defattr(-,root,root)
%config(noreplace) /etc/locales.conf
/usr/lib/gconv
/usr/lib/locale
/usr/sbin/locales-gen
/usr/share/i18n
/usr/share/locale

%files -n nscd
%defattr(-,root,root)
%config(noreplace) /etc/nscd.conf
/etc/init.d/nscd
/usr/sbin/nscd*

%changelog
* Wed Sep 29 2004 Oystein Viggen <oysteivi at trustix dot com>
- Patch tempfile issue 

* Wed Jan 14 2004 Chr. Toldnes <christht at trustix dot org> 2.3.2-13tr
- Ensure empty $LD_LIBRARY_PATH

* Thu Nov 25 2003 Erlend Midttun <erlendbm at trustix dot org> 2.3.2-12tr
- Big rebuild

* Fri Nov 14 2003 Chr. Toldnes <christht at trustix dot org> 2.3.2-11tr
- Fixed getgrouplist issues

* Fri Oct 31 2003 Chr. Toldnes <christht at trustix dot org> 2.3.2-10tr
- backport

* Sun Sep 28 2003 Chr. Toldnes <christht at tawie dot org> 2.3.2-9tsl
- port to tawie

* Mon Jun 30 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-8tr
- Rebuild with -tr suffix.
- Removed userdel as well.

* Sun Jun 29 2003 Janke Rnnblom <janron at trustix dot org> 2.3.2-8jr
- fixed nscd script
- removed groupdel from uninstall of nscd since userdel removes the group

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-7tr
- Big rebuild

* Fri May 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-6em
- Try to clean up filelist.

* Fri May 16 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-5em
- Added sscanf patch to compile against GCC 3.3

* Thu May 16 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-4em
- _PATH_VI -> /bin/vim
- chmod 644 ld.so.conf

* Tue Apr 22 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-3em
- Fixed uid/gid

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-2em
- Rebuilt against glibc 2.3.2.

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.3.2-1em
- New upstream.

* Thu Mar 20 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-19em
- Added XDR patches agains CA-2003-10.

* Fri Feb 28 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-18em
- Add nscd user with correct uid.

* Tue Feb 25 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-17em
- Trying again to add nscd user.
- Fix locales as reported by gda.

* Mon Jan 27 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-16em
- Incorrect group in glibc-locales.

* Thu Jan 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-15em
- Fixed initscript (#62).
- Added quotes to the getent lines.

* Thu Jan 16 2003 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-14em
- Change kernel-headers into linux-headers.

* Wed Dec  3 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-13ct
- The nscd initscript follows the policy.
- Separate source for the init script.

* Thu Oct 14 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-12ct
- Patched for several security issues. (Patch 9-11)

* Thu Oct  3 2002 Gerald Dachs <gda at trustix dot org> 2.2.5-11gd
- made /etc/ld.so.conf empty

* Tue Aug 27 2002 Erlend Midttun <erlendbm at trustix dot com> 2.2.5-10em
- Made changes to build with GCC 3.2.

* Thu Jul 25 2002 Gerald Dachs <gda at trustix dot org> 2.2.5-9gd
- Patch2 applied, because of buffer overflow in multiple DNS resolver
  libraries. CERT Advisory CA-2002-19.

* Thu Jul 18 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-8ct
- Moved from /etc/rc.d/init.d to /etc/init.d
- Added check before making nscd user and group
- en_US not default locale, using default 'C' instead, because of problems with
  sorting in glibc-2.2.x locales
- All locales stuff now back in -locales sub package.
- Must define 'C' in /etc/profile, but not in this package. /etc/profile belongs
  to the 'setup' package.

* Tue Jun 25 2002 Roland Kruse <rolandk at trustix dot com> 2.2.5-7rk
- Added glibc_post_upgrade program for %post section to avoid
  dependency of bash package (caused circular dependency)

* Wed Jun 12 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-6ct
- Force creation of system locales even if warnings have been issued.
- Even more filelist-cleanups.

* Tue Jun 11 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-5ct
- Correct chkconfig-handling of nscd.
- moved /etc/init.d/nscd to /etc/rc.d/init.d/
- This is for a new distro, removed 'Obsoletes:'
- more filelist cleanups.

* Mon Jun 10 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-4ct
- more filelist cleanups.
- Moved manpages to confirm with FSH
- Removed all the info-stuff.

* Fri Jun  7 2002 Christian H. Toldnes <christht at trustix dot com> 2.2.5-3ct
- Fixed /etc/locales.conf
- Made the .so.X-links actually be a part of the package.

* Thu May 30 2002 Christian H. Toldnes <christht at trustix dot com>
- Rebuild with -2ct releasetag.
- Todo: Fix /etc/locales.conf

* Mon Feb 18 2002 Christian H. Toldnes <christht at trustix dot com>
- Added /etc/locales.conf, and new locales-gen

* Wed Feb 13 2002 Erlend Midttun <erlendbm at trustix dot com>
- Strip .so's
- Added nsswitch.conf :)
- Added nsswitch.conf and ld.so.conf to file list.
- Added files for nscd again :)

* Mon Jan 21 2002 Christian H. Toldnes <christht at trustix dot com>
- New upstream version: 2.2.5
- Now let src-maintainer deside which locales are supported.
- Patched the ugly cpp-script to actually build the lot.
- Moved the locales generated into /usr/lib/locales (localedef).
- Only en_US generated by default in %post, rest by user.

* Wed Dec 10 2001 Christian H. Toldnes <christht at trustix dot com>
- Complete remake to fit glibc 2.2
- Data files for NLS into separate package (-locales).
- Most locales generated in post-installation script.
- Current version is: 2.2.4
