#include <sys/types.h>
#include <sys/wait.h>
#include <stdio.h>
#include <errno.h>
#include <unistd.h>
#include <sys/time.h>


/* Run a program and wait for it to terminate. Returns exit code,
   exits on catastrohic errors. */
int runprog(const char *path, char *const argv[])
{
    pid_t pid;
    int status;

    if ((pid = vfork()) == 0)
    {
        /* child */
        execv(path, argv);
        _exit(1);
    }
    else if (pid > 0)
    {
        /* parent */
        if (waitpid (0, &status, 0) != pid || !WIFEXITED (status))
            _exit (1);
        return WEXITSTATUS(status);
    }
    else _exit(1);
}


/* This is what normally would be in glibc's %post script:
   /sbin/ldconfig
   echo 'Generating default locale'
   echo -n 'en_US ISO-8859-1'
   localedef --inputfile=en_US --charmap=ISO-8859-1 --force en_US
   echo ' ...done'
   echo 'To get additional NLS, please install the glibc-locales package.'
   echo ''
*/
int main(void)
{
    int status;
    char *ldconfig_argv[]  = { "/sbin/ldconfig", NULL };
    char locale_premsg[]   = "Generating default locale\nen_US ISO-8859-1 ";
    char locale_postmsg[]  = "...done\n"
        "To get additional NLS, please install the glibc-locales package.\n\n";
    char errmsg[] = "...Failed!\n";
    char *localedef_argv[] = { "/usr/bin/localedef", "--inputfile=en_US",
                                "--charmap=ISO-8859-1", "--force", "en_US",
                               NULL };

    if ((status = runprog(ldconfig_argv[0], ldconfig_argv))) _exit(status);
    
    write(1, locale_premsg, sizeof(locale_premsg) - 1);
    if ((status = runprog(localedef_argv[0], localedef_argv)))
    {
        write(1, errmsg, sizeof(errmsg) - 1);
        _exit(status);
    }
    write(1, locale_postmsg, sizeof(locale_postmsg) - 1);    
    _exit(0);
}

int __libc_start_main (int (*main) (void), int argc, char **argv,
		       void (*init) (void), void (*fini) (void),
		       void (*rtld_fini) (void), void * stack_end)
{
  main();
  return 0;
}
